package com.theitbulls.actionbarex;

import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.SearchView;

public class MainActivity extends AppCompatActivity implements View.OnTouchListener {
    private boolean touched;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main_activity);

        findViewById(R.id.rlMain).setOnTouchListener(this);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.main, menu);
        MenuItem mnuSearch = menu.findItem(R.id.mnuSearch);

        final SearchView searchView = (SearchView) mnuSearch.getActionView();
        if(searchView != null) {
            searchView.setOnQueryTextListener(new SearchView.OnQueryTextListener() {
                @Override
                public boolean onQueryTextSubmit(String query) {
                    Toast.makeText(MainActivity.this, "You search for: " + searchView.getQuery(), Toast.LENGTH_SHORT).show();
                    return true;
                }

                @Override
                public boolean onQueryTextChange(String newText) {
                    return false;
                }
            });
        }
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        switch (item.getItemId()) {
            case R.id.mnuCall:
                Toast.makeText(this, "Clicked on Call Menu", Toast.LENGTH_SHORT).show();
            case R.id.mnuDelete:
                Toast.makeText(this, "Clicked on Delete Menu", Toast.LENGTH_SHORT).show();
            case R.id.mnuDone:
                Toast.makeText(this, "Clicked on Done Menu", Toast.LENGTH_SHORT).show();
            case R.id.mnuSpeak:
                Toast.makeText(this, "Clicked on Speak Menu", Toast.LENGTH_SHORT).show();
        }
        return false;
    }

    @Override
    public boolean onTouch(View view, MotionEvent motionEvent) {
        if (motionEvent.getAction() == MotionEvent.ACTION_DOWN) {
            toggleActionBar();
        }
        return false;
    }

    private void toggleActionBar() {
        if (touched) {
            getSupportActionBar().show();
        } else {
            getSupportActionBar().hide();
        }

        touched = !touched;
    }

    public void anotherWindow(View view) {
        Intent intent = new Intent(this, AnotherActivity.class);
        startActivity(intent);
    }

    public void customMenu(View view) {
        Intent intent = new Intent(this, CustomMenuActivity.class);
        startActivity(intent);
    }
}
